# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class VendorRequest(Model):
    """VendorRequest.

    :param vendor_code: The vendor code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 16 characters</span>
    :type vendor_code: str
    :param vendor_info: The vendor info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type vendor_info: str
    :param website: The vendor's website <span class='property-internal'>Must
     be between 0 and 255 characters</span>
    :type website: str
    :param address: The remit address of the vendor
    :type address: ~energycap.sdk.models.AddressChild
    """

    _validation = {
        'vendor_code': {'required': True, 'max_length': 16, 'min_length': 0},
        'vendor_info': {'required': True, 'max_length': 50, 'min_length': 0},
        'website': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'vendor_code': {'key': 'vendorCode', 'type': 'str'},
        'vendor_info': {'key': 'vendorInfo', 'type': 'str'},
        'website': {'key': 'website', 'type': 'str'},
        'address': {'key': 'address', 'type': 'AddressChild'},
    }

    def __init__(self, vendor_code, vendor_info, website=None, address=None):
        super(VendorRequest, self).__init__()
        self.vendor_code = vendor_code
        self.vendor_info = vendor_info
        self.website = website
        self.address = address
