# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TaskType(Model):
    """TaskType.

    :param task_type_id: The task type identifier
    :type task_type_id: int
    :param task_type_code: The code for task type
    :type task_type_code: str
    :param task_type_info: The task type information
    :type task_type_info: str
    """

    _attribute_map = {
        'task_type_id': {'key': 'taskTypeId', 'type': 'int'},
        'task_type_code': {'key': 'taskTypeCode', 'type': 'str'},
        'task_type_info': {'key': 'taskTypeInfo', 'type': 'str'},
    }

    def __init__(self, task_type_id=None, task_type_code=None, task_type_info=None):
        super(TaskType, self).__init__()
        self.task_type_id = task_type_id
        self.task_type_code = task_type_code
        self.task_type_info = task_type_info
